# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key_api_v1_api_keys_post(self) -> None:
        """Test case for create_api_key_api_v1_api_keys_post

        Create API Key
        """
        pass

    def test_create_api_key_api_v1_api_keys_post_0(self) -> None:
        """Test case for create_api_key_api_v1_api_keys_post_0

        Create Api Key
        """
        pass

    def test_create_client_api_v1_clients_post(self) -> None:
        """Test case for create_client_api_v1_clients_post

        Create Client
        """
        pass

    def test_create_provider_api_v1_providers_post(self) -> None:
        """Test case for create_provider_api_v1_providers_post

        Create Provider
        """
        pass

    def test_create_tenant_api_v1_tenants_post(self) -> None:
        """Test case for create_tenant_api_v1_tenants_post

        Create Tenant
        """
        pass

    def test_delete_client_api_v1_clients_client_id_delete(self) -> None:
        """Test case for delete_client_api_v1_clients_client_id_delete

        Delete Client
        """
        pass

    def test_delete_provider_api_v1_providers_provider_delete(self) -> None:
        """Test case for delete_provider_api_v1_providers_provider_delete

        Delete Provider
        """
        pass

    def test_delete_tenant_api_v1_tenants_tenant_id_delete(self) -> None:
        """Test case for delete_tenant_api_v1_tenants_tenant_id_delete

        Delete Tenant
        """
        pass

    def test_disable_provider_api_v1_providers_provider_disable_patch(self) -> None:
        """Test case for disable_provider_api_v1_providers_provider_disable_patch

        Disable Provider
        """
        pass

    def test_enable_provider_api_v1_providers_provider_enable_patch(self) -> None:
        """Test case for enable_provider_api_v1_providers_provider_enable_patch

        Enable Provider
        """
        pass

    def test_get_api_key_api_v1_api_keys_key_id_get(self) -> None:
        """Test case for get_api_key_api_v1_api_keys_key_id_get

        Get Api Key
        """
        pass

    def test_get_client_info_api_v1_clients_client_id_get(self) -> None:
        """Test case for get_client_info_api_v1_clients_client_id_get

        Get Client Info
        """
        pass

    def test_get_managers_api_v1_managers_get(self) -> None:
        """Test case for get_managers_api_v1_managers_get

        Get Managers
        """
        pass

    def test_get_provider_api_v1_providers_provider_get(self) -> None:
        """Test case for get_provider_api_v1_providers_provider_get

        Get Provider
        """
        pass

    def test_get_stats_api_v1_stats_get(self) -> None:
        """Test case for get_stats_api_v1_stats_get

        Get Stats
        """
        pass

    def test_get_tenant_api_v1_tenants_tenant_id_get(self) -> None:
        """Test case for get_tenant_api_v1_tenants_tenant_id_get

        Get Tenant
        """
        pass

    def test_get_user_api_v1_users_user_id_get(self) -> None:
        """Test case for get_user_api_v1_users_user_id_get

        Get User
        """
        pass

    def test_get_users_api_v1_users_get(self) -> None:
        """Test case for get_users_api_v1_users_get

        Get Users
        """
        pass

    def test_list_api_keys_api_v1_api_keys_get(self) -> None:
        """Test case for list_api_keys_api_v1_api_keys_get

        List Api Keys
        """
        pass

    def test_list_clients_api_v1_clients_get(self) -> None:
        """Test case for list_clients_api_v1_clients_get

        List Clients
        """
        pass

    def test_list_providers_api_v1_providers_get(self) -> None:
        """Test case for list_providers_api_v1_providers_get

        List Providers
        """
        pass

    def test_list_tenants_api_v1_tenants_get(self) -> None:
        """Test case for list_tenants_api_v1_tenants_get

        List Tenants
        """
        pass

    def test_revoke_api_key_api_v1_api_keys_key_id_delete(self) -> None:
        """Test case for revoke_api_key_api_v1_api_keys_key_id_delete

        Revoke Api Key
        """
        pass

    def test_update_api_key_api_v1_api_keys_key_id_put(self) -> None:
        """Test case for update_api_key_api_v1_api_keys_key_id_put

        Update Api Key
        """
        pass

    def test_update_client_api_v1_clients_client_id_put(self) -> None:
        """Test case for update_client_api_v1_clients_client_id_put

        Update Client
        """
        pass

    def test_update_provider_api_v1_providers_provider_put(self) -> None:
        """Test case for update_provider_api_v1_providers_provider_put

        Update Provider
        """
        pass

    def test_update_tenant_api_v1_tenants_tenant_id_put(self) -> None:
        """Test case for update_tenant_api_v1_tenants_tenant_id_put

        Update Tenant
        """
        pass

    def test_validate_api_key_api_v1_api_keys_validate_api_key_get(self) -> None:
        """Test case for validate_api_key_api_v1_api_keys_validate_api_key_get

        Validate Api Key
        """
        pass


if __name__ == '__main__':
    unittest.main()
