# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.api.admin_authentication_api import AdminAuthenticationApi


class TestAdminAuthenticationApi(unittest.TestCase):
    """AdminAuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminAuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_admin_login_api_v1_auth_login_post(self) -> None:
        """Test case for admin_login_api_v1_auth_login_post

        Admin Login
        """
        pass

    def test_admin_logout_api_v1_auth_logout_post(self) -> None:
        """Test case for admin_logout_api_v1_auth_logout_post

        Admin Logout
        """
        pass

    def test_admin_refresh_token_api_v1_auth_refresh_post(self) -> None:
        """Test case for admin_refresh_token_api_v1_auth_refresh_post

        Admin Refresh Token
        """
        pass

    def test_me_api_v1_auth_me_get(self) -> None:
        """Test case for me_api_v1_auth_me_get

        Me
        """
        pass

    def test_signup_api_v1_auth_signup_post(self) -> None:
        """Test case for signup_api_v1_auth_signup_post

        Signup
        """
        pass

    def test_social_login_api_v1_auth_social_login_post(self) -> None:
        """Test case for social_login_api_v1_auth_social_login_post

        Social Login
        """
        pass


if __name__ == '__main__':
    unittest.main()
