# coding: utf-8

# flake8: noqa

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AdminApi",
    "AdminAuthenticationApi",
    "HealthApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiKeyCreate",
    "ApiKeyCreateResponse",
    "ApiKeyListResponse",
    "ApiKeyResponse",
    "ApiKeyStatus",
    "ApiKeyUpdate",
    "ClientAuthMethods",
    "ClientCreate",
    "ClientResponse",
    "ClientUpdate",
    "Domain",
    "ExternalAccount",
    "HTTPValidationError",
    "InLineClientConfig",
    "ManagementLoginRequest",
    "ManagementRefreshTokenRequest",
    "ManagementSignupRequest",
    "ManagementSignupResponse",
    "ManagementSocialLoginRequest",
    "ManagementTokenResponse",
    "ManagementUserResponse",
    "PaginationResultClientResponse",
    "PaginationResultTenantResponse",
    "PaginationResultUserWithExternalAccounts",
    "ProviderSettingsCreate",
    "ProviderSettingsResponse",
    "ProviderSettingsUpdate",
    "ProviderType",
    "TenantCreateRequest",
    "TenantResponse",
    "TenantUpdateRequest",
    "UserStatus",
    "UserWithExternalAccounts",
    "ValidationError",
    "ValidationErrorLocInner",
]

# import apis into sdk package
from binoauth.admin.api.admin_api import AdminApi as AdminApi
from binoauth.admin.api.admin_authentication_api import AdminAuthenticationApi as AdminAuthenticationApi
from binoauth.admin.api.health_api import HealthApi as HealthApi

# import ApiClient
from binoauth.admin.api_response import ApiResponse as ApiResponse
from binoauth.admin.api_client import ApiClient as ApiClient
from binoauth.admin.configuration import Configuration as Configuration
from binoauth.admin.exceptions import OpenApiException as OpenApiException
from binoauth.admin.exceptions import ApiTypeError as ApiTypeError
from binoauth.admin.exceptions import ApiValueError as ApiValueError
from binoauth.admin.exceptions import ApiKeyError as ApiKeyError
from binoauth.admin.exceptions import ApiAttributeError as ApiAttributeError
from binoauth.admin.exceptions import ApiException as ApiException

# import models into sdk package
from binoauth.admin.models.api_key_create import ApiKeyCreate as ApiKeyCreate
from binoauth.admin.models.api_key_create_response import ApiKeyCreateResponse as ApiKeyCreateResponse
from binoauth.admin.models.api_key_list_response import ApiKeyListResponse as ApiKeyListResponse
from binoauth.admin.models.api_key_response import ApiKeyResponse as ApiKeyResponse
from binoauth.admin.models.api_key_status import ApiKeyStatus as ApiKeyStatus
from binoauth.admin.models.api_key_update import ApiKeyUpdate as ApiKeyUpdate
from binoauth.admin.models.client_auth_methods import ClientAuthMethods as ClientAuthMethods
from binoauth.admin.models.client_create import ClientCreate as ClientCreate
from binoauth.admin.models.client_response import ClientResponse as ClientResponse
from binoauth.admin.models.client_update import ClientUpdate as ClientUpdate
from binoauth.admin.models.domain import Domain as Domain
from binoauth.admin.models.external_account import ExternalAccount as ExternalAccount
from binoauth.admin.models.http_validation_error import HTTPValidationError as HTTPValidationError
from binoauth.admin.models.in_line_client_config import InLineClientConfig as InLineClientConfig
from binoauth.admin.models.management_login_request import ManagementLoginRequest as ManagementLoginRequest
from binoauth.admin.models.management_refresh_token_request import ManagementRefreshTokenRequest as ManagementRefreshTokenRequest
from binoauth.admin.models.management_signup_request import ManagementSignupRequest as ManagementSignupRequest
from binoauth.admin.models.management_signup_response import ManagementSignupResponse as ManagementSignupResponse
from binoauth.admin.models.management_social_login_request import ManagementSocialLoginRequest as ManagementSocialLoginRequest
from binoauth.admin.models.management_token_response import ManagementTokenResponse as ManagementTokenResponse
from binoauth.admin.models.management_user_response import ManagementUserResponse as ManagementUserResponse
from binoauth.admin.models.pagination_result_client_response import PaginationResultClientResponse as PaginationResultClientResponse
from binoauth.admin.models.pagination_result_tenant_response import PaginationResultTenantResponse as PaginationResultTenantResponse
from binoauth.admin.models.pagination_result_user_with_external_accounts import PaginationResultUserWithExternalAccounts as PaginationResultUserWithExternalAccounts
from binoauth.admin.models.provider_settings_create import ProviderSettingsCreate as ProviderSettingsCreate
from binoauth.admin.models.provider_settings_response import ProviderSettingsResponse as ProviderSettingsResponse
from binoauth.admin.models.provider_settings_update import ProviderSettingsUpdate as ProviderSettingsUpdate
from binoauth.admin.models.provider_type import ProviderType as ProviderType
from binoauth.admin.models.tenant_create_request import TenantCreateRequest as TenantCreateRequest
from binoauth.admin.models.tenant_response import TenantResponse as TenantResponse
from binoauth.admin.models.tenant_update_request import TenantUpdateRequest as TenantUpdateRequest
from binoauth.admin.models.user_status import UserStatus as UserStatus
from binoauth.admin.models.user_with_external_accounts import UserWithExternalAccounts as UserWithExternalAccounts
from binoauth.admin.models.validation_error import ValidationError as ValidationError
from binoauth.admin.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner
