# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ClientAuthMethods(str, Enum):
    """
    ClientAuthMethods
    """

    """
    allowed enum values
    """
    PASSWORD = 'password'
    MAGIC_LINK = 'magic_link'
    PHONE_OTP = 'phone_otp'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ClientAuthMethods from a JSON string"""
        return cls(json.loads(json_str))
