# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.models.api_key_status import ApiKeyStatus

class TestApiKeyStatus(unittest.TestCase):
    """ApiKeyStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiKeyStatus(self):
        """Test ApiKeyStatus"""
        # inst = ApiKeyStatus()

if __name__ == '__main__':
    unittest.main()
