# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.models.management_signup_response import ManagementSignupResponse

class TestManagementSignupResponse(unittest.TestCase):
    """ManagementSignupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ManagementSignupResponse:
        """Test ManagementSignupResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ManagementSignupResponse`
        """
        model = ManagementSignupResponse()
        if include_optional:
            return ManagementSignupResponse(
                user = binoauth.admin.models.management_user_response.ManagementUserResponse(
                    id = null,
                    email = '',
                    role = '',
                    image = '',
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return ManagementSignupResponse(
                user = binoauth.admin.models.management_user_response.ManagementUserResponse(
                    id = null,
                    email = '',
                    role = '',
                    image = '',
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testManagementSignupResponse(self):
        """Test ManagementSignupResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
