# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.models.pagination_result_tenant_response import PaginationResultTenantResponse

class TestPaginationResultTenantResponse(unittest.TestCase):
    """PaginationResultTenantResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginationResultTenantResponse:
        """Test PaginationResultTenantResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginationResultTenantResponse`
        """
        model = PaginationResultTenantResponse()
        if include_optional:
            return PaginationResultTenantResponse(
                data = [
                    binoauth.admin.models.tenant_response.TenantResponse(
                        id = '',
                        schema_name = '',
                        owner_id = '',
                        domains = [
                            binoauth.admin.models.domain.Domain(
                                domain = '',
                                is_primary = True,
                                is_subdomain = True,
                                is_active = True,
                                id = '',
                                tenant_id = '',
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                                verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ],
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                page = 56,
                limit = 56,
                next = 56,
                prev = 56
            )
        else:
            return PaginationResultTenantResponse(
                data = [
                    binoauth.admin.models.tenant_response.TenantResponse(
                        id = '',
                        schema_name = '',
                        owner_id = '',
                        domains = [
                            binoauth.admin.models.domain.Domain(
                                domain = '',
                                is_primary = True,
                                is_subdomain = True,
                                is_active = True,
                                id = '',
                                tenant_id = '',
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                                verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ],
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                page = 56,
                limit = 56,
                next = 56,
                prev = 56,
        )
        """

    def testPaginationResultTenantResponse(self):
        """Test PaginationResultTenantResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
