# coding: utf-8

"""
    Identity Provider - Admin API

    Admin API endpoints (public tenant only)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from binoauth.admin.models.client_create import ClientCreate

class TestClientCreate(unittest.TestCase):
    """ClientCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientCreate:
        """Test ClientCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientCreate`
        """
        model = ClientCreate()
        if include_optional:
            return ClientCreate(
                name = '',
                redirect_uris = [
                    ''
                    ],
                allowed_scopes = [
                    ''
                    ],
                client_type = 'confidential',
                grant_types = [
                    ''
                    ],
                client_config = binoauth.admin.models.in_line_client_config.InLineClientConfig(
                    auth_methods = [
                        'password'
                        ],
                    link = '',
                    logo_uri = '',
                    description = '',
                    include_in_dashboard = True, )
            )
        else:
            return ClientCreate(
                name = '',
                redirect_uris = [
                    ''
                    ],
                allowed_scopes = [
                    ''
                    ],
                grant_types = [
                    ''
                    ],
                client_config = binoauth.admin.models.in_line_client_config.InLineClientConfig(
                    auth_methods = [
                        'password'
                        ],
                    link = '',
                    logo_uri = '',
                    description = '',
                    include_in_dashboard = True, ),
        )
        """

    def testClientCreate(self):
        """Test ClientCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
